@@ -51,14 +51,11 @@ Nothing.
 
 =cut
 
-use 5.008008;
 use strict;
 use warnings;
 use base qw(Win32::SqlServer::DTS::Assignment);
 use Hash::Util qw(lock_keys);
 
-our $VERSION = '0.02';
-
 =head2 METHODS
 
 Inherits all methods from C<Win32::SqlServer::DTS::Assignment>.
