@@ -45,15 +45,12 @@ Nothing.
 
 =cut
 
-use 5.008008;
 use strict;
 use warnings;
 use Carp;
 use base qw(Win32::SqlServer::DTS::Task Class::Accessor);
 use Hash::Util qw(lock_keys);
 
-our $VERSION = '0.03';
-
 =head2 METHODS
 
 All methods from L<Win32::SqlServer::DTS::Task|Win32::SqlServer::DTS::Task> are also available.
